@@ -6,7 +6,9 @@ perl -Ilib scripts/generate.demo.pl
 perl -Ilib scripts/code.attributes2html.pl
 perl -Ilib scripts/stt2html.pl
 
-# $DR is my web server's doc root and $PM is Perl-modules/html/graphviz2.marpa.
+# $DR is my web server's doc root.
+
+PM=Perl-modules/html/graphviz2.marpa
 
 cp html/*.html html/*.svg $DR/$PM
 
